@@ -6,7 +6,7 @@ use base qw( XML::Liberal::Remedy );
 sub apply {
     my $self = shift;
     my($xml_ref) = @_;
-    my $match = $$xml_ref =~ s{(&#(?:(\d+)|x([0-9a-f]{4}));)}{
+    my $match = $$xml_ref =~ s{(&#(?:(\d+)|x([0-9a-f]{2,4}));)}{
         ($2 && is_low_ascii($2)) || ($3 && is_low_ascii(hex($3)))
             ? '' : $1;
     }eg;
@@ -16,9 +16,11 @@ sub apply {
     return;
 }
 
+my %is_low_ascii = map { $_ => 1 } (0..8, 11..12, 14..31, 127);
+
 sub is_low_ascii {
     my $num = shift;
-    $num <= 31 || $num == 127;
+    $is_low_ascii{$num};
 }
 
 1;
